﻿using Microsoft.AspNetCore.Mvc;
using System.Transactions;
using UnivateProperties_API.Model.ProcessFlow;
using UnivateProperties_API.Repository;

namespace UnivateProperties_API.Controllers.ProcessFlow
{
    [Route("api/[controller]")]
    [ApiController]
    public class BidController : ControllerBase
    {
        private readonly IRepository<BidItem> _Repo;

        public BidController(IRepository<BidItem> repo)
        {
            _Repo = repo;
        }

        [HttpGet]
        public IActionResult Get()
        {
            var items = _Repo.GetAll();
            return new OkObjectResult(items);
        }

        [HttpGet("{id}")]
        public IActionResult Get(int id)
        {
            var item = _Repo.Get(x => x.Id == id);
            return new OkObjectResult(item);
        }

        [HttpPost]
        public IActionResult Post([FromBody] BidItem item)
        {
            using (var scope = new TransactionScope())
            {
                _Repo.Insert(item);
                scope.Complete();
                return CreatedAtAction(nameof(Get), new { id = item.Id }, item);
            }
        }

        [HttpPut("{id}")]
        public IActionResult Put([FromBody] BidItem item)
        {
            if (item != null)
            {
                using (var scope = new TransactionScope())
                {
                    _Repo.Update(item);
                    scope.Complete();
                    return new OkResult();
                }
            }
            return new NoContentResult();
        }

        [HttpDelete("{id}")]
        public IActionResult Delete(int id)
        {
            _Repo.RemoveAtId(id);
            return new OkResult();
        }
    }
}
