﻿using Microsoft.EntityFrameworkCore;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using UnivateProperties_API.Context;
using UnivateProperties_API.Model.ProcessFlow;

namespace UnivateProperties_API.Repository.ProccessFlow
{
    public class BidRepository : IRepository<BidItem>
    {
        private readonly DataContext _dbContext;

        public BidRepository(DataContext dbContext)
        {
            _dbContext = dbContext;
        }

        public List<BidItem> Get(Func<BidItem, bool> where)
        {
            return _dbContext.BidItems.Where(where).ToList();
        }

        public List<BidItem> GetAll()
        {
            return _dbContext.BidItems.ToList();
        }

        public BidItem GetDetailed(Func<BidItem, bool> first)
        {
            var item = _dbContext.BidItems.FirstOrDefault(first);
            return item;
        }

        public List<BidItem> GetDetailedAll()
        {
            return GetAll();
        }

        public void Insert(BidItem item)
        {
            _dbContext.Add(item);
            Save();
        }

        public void Insert(IEnumerable<BidItem> items)
        {
            foreach (var item in items)
            {
                _dbContext.Add(item);
            }
            Save();
        }

        public void Remove(BidItem item)
        {
            var i = _dbContext.BidItems.Find(item);
            _dbContext.BidItems.Remove(i);
            Save();
        }

        public void Remove(IEnumerable<BidItem> items)
        {
            foreach (var item in items)
            {
                var i = _dbContext.BidItems.Find(item);
                _dbContext.BidItems.Remove(i);
            }
            Save();
        }

        public void RemoveAtId(int item)
        {
            var i = _dbContext.BidItems.Find(item);
            _dbContext.BidItems.Remove(i);
            Save();
        }

        public void Save()
        {
            _dbContext.SaveChanges();
        }

        public void Update(BidItem item)
        {
            _dbContext.Entry(item).State = EntityState.Modified;
            Save();
        }
    }
}
